﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Samples;

namespace HostAnyControl
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {

        private String pointString { get; set; }
        public GridDataViewModel ViewModel { get { return FindResource("ViewModelDataSource") as GridDataViewModel; } set { } }

        public Window1()
        {
            InitializeComponent();

            MyGrid.EditModeStarting += new EventHandler<Infragistics.Windows.DataPresenter.Events.EditModeStartingEventArgs>(MyGrid_EditModeStarting);
            MyGrid.EditModeEnded += new EventHandler<Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs>(MyGrid_EditModeEnded);
        }

        void MyGrid_EditModeStarting(object sender, Infragistics.Windows.DataPresenter.Events.EditModeStartingEventArgs e)
        {
            if (e.Cell.Field.Name == "DataPoint")
            {
                if (e.Cell.Record.DataItem != null)
                {
                    // get id from selected record
                    object record = e.Cell.Record.DataItem;
                    int id = (int)record.GetType().GetProperty("ID").GetValue(record, null);

                    // get data item from list of complex datatype
                    ComplexDataType editData = ViewModel.MyData.Where(p => p.ID == id).First();

                    // set point as data for editing cell to be used with custom editor
                    e.Cell.Value = editData;
                }
            }
        }

        void MyGrid_EditModeEnded(object sender, Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs e)
        {
            if (e.Cell.Field.Name == "DataPoint")
            {
                if (e.Cell.Record.DataItem != null)
                {
                    // format complex data back to string render data
                    object record = e.Cell.Record.DataItem;
                    int id = (int)record.GetType().GetProperty("ID").GetValue(record, null);

                    // get data item from list of complex datatype for updating DataPoint values
                    ComplexDataType editData = ViewModel.MyData.Where(p => p.ID == id).First();

                    // The following appears to not be necessary. 
                    // The DataPoint is being set in ComplexDataTypeEditorX and Y property setters.
                    //editData.DataPoint = ((ComplexDataType)e.Cell.Value).DataPoint;

                    // We do need to make sure that GridData gets updated too, otherwise,
                    // the possiblilty of the value being reverted exists since the Grid is bound to this collection.
                    GridDataType gridData = ViewModel.GridData.Where(p => p.ID == id).First();
                    gridData.DataPoint = editData.GetPointAsString();

                    // set grid value back to string
                    e.Cell.Value = gridData.DataPoint;
                }
            }
        }
    }
}
